componenttools.all_are_thread_contiguous_components
===================================================

.. autofunction:: abjad.tools.componenttools.all_are_thread_contiguous_components.all_are_thread_contiguous_components
